@@ -87,9 +87,12 @@ class Service:
                         "--global.checkNewVersion=false",
                         "--global.sendAnonymousUsage=false",
                         "--entryPoints.http.address=:80",
-                        "--entryPoints.http.http.middlewares=compress@docker,https-redirect@docker",
+                        "--entryPoints.http.http.redirections.entryPoint.to=https",
+                        "--entryPoints.http.http.redirections.entryPoint.scheme=https",
+                        "--entryPoints.http.http.middlewares=compress@docker",
                         "--entryPoints.https.address=:443",
                         "--entryPoints.https.http.middlewares=compress@docker,secured@docker",
+                        "--entryPoints.https.http.tls.certResolver=letsencrypt",
                         "--api=true",
                         "--api.insecure=true",
                         "--api.dashboard=true",
@@ -135,7 +138,7 @@ class Service:
                         "traefik.http.routers.traefik.rule": "Host(`" + self.url + "`)",
                         "traefik.http.middlewares.compress.compress": "true",
                         "traefik.http.routers.traefik.service": "api@internal",
-                        "traefik.http.middlewares.secured.chain.middlewares": "https-redirect,default-headers",
+                        "traefik.http.middlewares.secured.chain.middlewares": "default-headers",
                         "traefik.http.middlewares.https-redirect.redirectScheme.scheme": "https",
                         "traefik.http.middlewares.https-redirect.redirectScheme.permanent": "true",
                         # "traefik.http.middlewares.default-whitelist.ipwhitelist.sourceRange": "10.0.0.0/8,192.168.0.0/16,127.0.0.1/32,172.0.0.0/8",
